==> bplan-base-globals-1.1.0-0b4347.zip: lang/it/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'it',
    'language' => 'Italiano',
    'locale' => 'it_IT',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Cent',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd/m/Y',
    'datetime.format'   => 'd/m/Y H:i',
    'datetime.format+'  => 'd/m/Y H:i:s',
    'datetime.format-+' => 'd/m/Y H:i',
    'datetime.format++' => 'd/m/Y H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Attiva',
    'action.add'           => 'Aggiungi',
    'action.cancel'        => 'Annulla',
    'action.cancel-upload' => 'Annulla caricamento',
    'action.change'        => 'Cambia',
    'action.close'         => 'Chiudi',
    'action.confirm'       => 'Conferma',
    'action.deactivate'    => 'Disattiva',
    'action.delete'        => 'Elimina',
    'action.edit'          => 'Modifica',
    'action.import'        => 'Importa',
    'action.print'         => 'Stampa',
    'action.save'          => 'Salva',
    'action.search'        => 'Cerca',
    'action.sync'          => 'Sincronizza',
    'action.upload'        => 'Carica file',
    'action.verify'        => 'Verifica',
    'action.view'          => 'Visualizza',

    'languages' => [
        'bg' => 'Bulgaro',
        'de' => 'Tedesco',
        'en' => 'Inglese',
        'es' => 'Spagnolo',
        'fr' => 'Francese',
        'hu' => 'Ungherese',
        'it' => 'Italiano',
        'lt' => 'Lituano',
        'pl' => 'Polacco',
        'ro' => 'Rumeno',
        'ru' => 'Russo',
        'tr' => 'Turco',
        'uk' => 'Ucraino',
    ],

    'option.yes' => 'Sì',
    'option.no'  => 'No',

    'required-hint'   => 'I campi contrassegnati (<span class="required-marker">:marker</span>) sono obbligatori',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Seleziona -- ',

    'status.active'   => 'Attivo',
    'status.expired'  => 'Scaduto',
    'status.inactive' => 'Inattivo',
    'status.invalid'  => 'Non valido',
    'status.loading'  => 'Caricamento...',
    'status.not-set'  => 'Non impostato',
    'status.valid'    => 'Valido',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/it/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'it',
    'language' => 'Italiano',
    'locale' => 'it_IT',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Cent',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd/m/Y',
    'datetime.format'   => 'd/m/Y H:i',
    'datetime.format+'  => 'd/m/Y H:i:s',
    'datetime.format-+' => 'd/m/Y H:i',
    'datetime.format++' => 'd/m/Y H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Attiva',
    'action.add'           => 'Aggiungi',
    'action.cancel'        => 'Annulla',
    'action.cancel-upload' => 'Annulla caricamento',
    'action.change'        => 'Cambia',
    'action.close'         => 'Chiudi',
    'action.confirm'       => 'Conferma',
    'action.deactivate'    => 'Disattiva',
    'action.delete'        => 'Elimina',
    'action.edit'          => 'Modifica',
    'action.import'        => 'Importa',
    'action.print'         => 'Stampa',
    'action.save'          => 'Salva',
    'action.search'        => 'Cerca',
    'action.sync'          => 'Sincronizza',
    'action.upload'        => 'Carica file',
    'action.verify'        => 'Verifica',
    'action.view'          => 'Visualizza',

    'languages' => [
        'bg' => 'Bulgaro',
        'de' => 'Tedesco',
        'en' => 'Inglese',
        'es' => 'Spagnolo',
        'fr' => 'Francese',
        'hu' => 'Ungherese',
        'it' => 'Italiano',
        'lt' => 'Lituano',
        'pl' => 'Polacco',
        'ro' => 'Rumeno',
        'ru' => 'Russo',
        'tr' => 'Turco',
        'uk' => 'Ucraino',
    ],

    'option.yes' => 'Sì',
    'option.no'  => 'No',

    'required-hint'   => 'I campi contrassegnati (<span class="required-marker">:marker</span>) sono obbligatori',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Nessuna opzione disponibile',
    'select-option.please-select'        => ' -- Seleziona -- ',

    'status.active'   => 'Attivo',
    'status.expired'  => 'Scaduto',
    'status.inactive' => 'Inattivo',
    'status.invalid'  => 'Non valido',
    'status.loading'  => 'Caricamento...',
    'status.not-set'  => 'Non impostato',
    'status.valid'    => 'Valido',

];
